package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @ author    :TXF
 * @ time      :2021/10/28 13:28
 */

@FeignClient(value = "DAL-OMS-API-DEV", url = "${openfeign.OMSFeign.url}")
public interface OmsFeign {

     /*
    OmstruckOrderController
     */

    @PostMapping("api/v1/oms/omstruckorders/getAllTruckOrder")
    public Map<String, Object> getAllTruckOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("orderStatus") Integer orderStatus,
                                          @RequestParam("planId") Integer planId,
                                          @RequestParam("orderType") Integer orderType,
                                          @RequestParam("fuelOrder") Integer fuelOrder
                                                );

    @PostMapping("api/v1/oms/omstruckorders/getAllTruckOrderReturnListMap")
    public Map<String, Object> getAllTruckOrderReturnListMap(
            @RequestParam("orderStatus") Integer orderStatus,
            @RequestParam("planId") Integer planId,
            @RequestParam("orderType") Integer orderType);

    @PostMapping("api/v1/oms/omstruckorders/getAllCapacity")
    public Map<String, Object> getAllCapacity(@RequestBody(required=false) Map<String,Object> mapValue,
                                        @RequestParam("apiId") Integer apiId,
                                        @RequestParam("pageNum") Integer pageNum,
                                        @RequestParam("pageSize") Integer pageSize,
                                        @RequestParam("carrierId") Integer carrierId);

    @PostMapping("api/v1/oms/omstruckorders/addPurOrder")
    public Map<String, Object> addPurOrder(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/oms/omstruckorders/updateOrder")
    public Map<String, Object> updateOrder(@RequestBody Map<String, Object> map);

    @PostMapping("api/v1/oms/omstruckorders/dispatchOrder/{orderId}")
    public Map<String, Object> dispatchOrder(@RequestBody(required = false) Map<String, Object> map);

    @PostMapping("api/v1/oms/omstruckorders/deleteOrder")
    public Map<String, Object> deleteOrder(@RequestBody(required = false) Map<String, Object> map,
                                     @RequestParam("planId") Integer planId);

    @PostMapping("api/v1/oms/omstruckorders/driverReceiveOrRefuse/{orderId}")
    public Map<String, Object> driverReceiveOrRefuse(@PathVariable("orderId") Integer orderId,
                                               @RequestParam("orderReceiveStatus") Integer orderReceiveStatus);

    @PostMapping("api/v1/oms/omstruckorders/getReceiveRefuseOrder/{orderReceiveStatus}")
    public Map<String, Object> getReceiveRefuseOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @PathVariable("orderReceiveStatus") Integer orderReceiveStatus,
                                               @RequestParam("orderType") Integer orderType,
                                               @RequestParam("orderStatus") Integer orderStatus);

    @PostMapping("api/v1/oms/omstruckorders/sendMesToDriver")
    public Map<String, Object> sendMesToDriver(@RequestParam("capacityNumber") String capacityNumber,
                                         @RequestParam("orderStatus") Integer orderStatus);


    @PostMapping("api/v1/oms/omstruckorders/getRefuseOrderByCapacityNum")
    public Map<String, Object> sendMesToDriver(@RequestParam("capacityNumber") String capacityNumber);


    @PostMapping("api/v1/oms/omstruckorders/getOrderMesByOrderNum/{orderId}")
    public Map<String, Object> getOrderMesByOrderNum(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/oms/omstruckorders/selectPlaceAndTime/{orderId}")
    public Map<String, Object> selectPlaceAndTime(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/oms/omstruckorders/selectOrderByOrderId/{orderId}")
    public Map<String, Object> selectOrderByOrderId(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/oms/omstruckorders/getTransportDispatch/{orderReceiveStatus}")
    public Map<String, Object> getTransportDispatch(@RequestBody(required=false) Map<String,Object> mapValue,
                                              @RequestParam("apiId") Integer apiId,
                                              @RequestParam("pageNum") Integer pageNum,
                                              @RequestParam("pageSize") Integer pageSize,
                                              @PathVariable("orderReceiveStatus") Integer orderReceiveStatus,
                                              @RequestParam("orderType") Integer orderType,
                                              @RequestParam("orderStatus") Integer orderStatus,
                                                    @RequestParam("fuelOrder") Integer fuelOrder);
    /**
     * 展示承运商接收销售公司已接受的销售订单
     * @param carrierId
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "api/v1/oms/omstruckorders/getSaleOrderForCarrierList/{carrierId}",method = RequestMethod.POST)
    Map<String,Object> getSaleOrderForCarrierList(@PathVariable("carrierId") Integer carrierId,
                                                  @RequestParam Integer apiId,
                                                  @RequestParam Integer pageNum,
                                                  @RequestParam Integer pageSize);

    /**
     * 查询所有已经接收的焦炭发运日计划
     * @param carrierId
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "api/v1/oms/omstruckorders/getCokeDayPlanAndRecivedList",method = RequestMethod.POST)
    Map<String,Object> getCokeDayPlanAndRecivedList(@PathVariable("carrierId") Integer carrierId,
                                                    @RequestParam Integer apiId,
                                                    @RequestParam Integer pageNum,
                                                    @RequestParam Integer pageSize);
    /**
     *查询所有已经接收的水渣发运日计划
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @RequestMapping(value = "api/v1/oms/omstruckorders/getWaterSlagDayPlanAndRecivedList",method = RequestMethod.POST)
    Map<String,Object> getWaterSlagDayPlanAndRecivedList(@PathVariable("carrierId") Integer carrierId,
                                                         @RequestParam Integer apiId,
                                                         @RequestParam Integer pageNum,
                                                         @RequestParam Integer pageSize);
}

